@@ -1,13 +1,14 @@
 """directories is used to generate the necessary directory structures."""
 from logging import INFO, Logger
+from os import PathLike
 from pathlib import Path
 from typing import Iterable, MutableSequence, Set
 
-from _typeshed import StrPath
-
 from ansible_generator.log import setup_logger
 from ansible_generator.utilities import join_cwd_and_directory_path
 
+StrPath = str | PathLike[str]
+
 
 def create_directory_layout(
     projects: Iterable[str],
